@@ -8,7 +8,7 @@
 
 #define ks_lt_index(a, b) ((a).value < (b).value)
 
-#ifdef  USE_SSE
+#if   defined(USE_SSE)
 #include <emmintrin.h>
 #endif
 
@@ -338,7 +338,7 @@
 
 
 
-#ifdef USE_SSE
+#if defined(USE_SSE)
 /*
 From https://github.com/herumi/fmath/blob/master/fastexp.cpp
 
@@ -524,4 +524,4 @@ static inline void remez9_0_log2_sse(double *values, size_t num)
 
 
 
-#endif
\ No newline at end of file
+#endif
